# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red Hat
%define base_flavor       redhat
%define base_prefix       pki

## Product Definitions
%define base_system       Certificate System
%define base_product      PKI Common Framework
%define base_component    common
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_prefix}-%{base_component}
%define base_version      8.1.3
%define base_release      2
%define base_phase        %{nil}
%define base_group        System Environment/Base
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Subpackage Header Definitions
%define javadoc_summary   %{base_summary} Javadocs
%define javadoc_group     Development/Documentation

## Legacy Definitions
%define legacy_prefix     rhpki
%define legacy_name       %{legacy_prefix}-%{base_component}

## Helper Definitions
%define pki_jdk           java-devel >= 1:1.6.0
%define pki_jre           java >= 1:1.6.0
# Override the default 'pki_jdk' and 'pki_jre' on Fedora 8 platforms
%{?fc8:%define pki_jdk    java-devel >= 1.7.0}
%{?fc8:%define pki_jre    java >= 1.7.0}
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5, %{base_flavor}-%{base_name}-ui >= 8.1.0, %{base_prefix}-util >= 8.1.0, %{pki_jdk}, jpackage-utils >= 1.7.3, jss >= 4.2.6-15, ldapjdk >= 4.18, osutil >= 1.2.0, symkey >= 1.2.0, velocity >= 1.4, xalan-j2, xerces-j2, nuxwdog-client-java >= 1.0.1

## Without Requires something, rpmbuild will abort!
Requires:       %{base_name}-ui, %{base_prefix}-java-tools >= 8.1.0, %{base_prefix}-setup >= 8.1.0, %{pki_jre}, rhgb >= 0.16.4, symkey >= 1.2.0, tomcatjss >= 1.1.4, velocity >= 1.4, jss >= 4.2.6-15, nuxwdog-client-java >= 1.0.1, nuxwdog-devel >= 1.0.1, nuxwdog >= 1.0.1
Provides:       %{legacy_name}
Obsoletes:      %{legacy_name}


## This package conflicts with the following packages!
Conflicts:      tomcat-native


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

Patch0:         pki-common-displayCRL-profileProcess-multiple-XSS.patch 



%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{base_entity} %{base_product} is required by the following four
%{base_entity} PKI subsystems:

    the %{pki_ca},
    the %{pki_drm},
    the %{pki_ocsp}, and
    the %{pki_tks}.



###############################################################################
###                    S U B P A C K A G E   H E A D E R                    ###
###############################################################################

%package javadoc
Summary:    %{javadoc_summary}
Group:      %{javadoc_group}


## Subpackages should always use package = version-release
Requires:   %{base_name} = %{version}-%{release}


%description javadoc
%{javadoc_summary}

This documentation pertains exclusively to version %{version} of
the %{base_entity} %{base_product}.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q


## This package currently contains no patches!
#%patch0
# patches

%patch0 -p3  


###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
ant -Dspecfile=%{base_name}.spec



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
cd dist/binary
unzip %{name}-%{version}.zip -d ${RPM_BUILD_ROOT}
cd ${RPM_BUILD_ROOT}/usr/share/java/%{base_prefix}
mv certsrv.jar certsrv-%{version}.jar
ln -s certsrv-%{version}.jar certsrv.jar
mv cms.jar cms-%{version}.jar
ln -s cms-%{version}.jar cms.jar
mv cmsbundle.jar cmsbundle-%{version}.jar
ln -s cmsbundle-%{version}.jar cmsbundle.jar
mv cmscore.jar cmscore-%{version}.jar
ln -s cmscore-%{version}.jar cmscore.jar
mkdir -p ${RPM_BUILD_ROOT}/var/lib/tomcat5/common/lib
cd ${RPM_BUILD_ROOT}/var/lib/tomcat5/common/lib
ln -s /usr/share/java/ldapjdk.jar ldapjdk.jar
ln -s /usr/share/java/velocity.jar velocity.jar
ln -s /usr/share/java/xalan-j2.jar xalan-j2.jar
ln -s /usr/share/java/xerces-j2.jar xerces-j2.jar
ln -s /usr/share/java/%{base_prefix}/cmsutil.jar cmsutil.jar
ln -s /usr/share/java/%{base_prefix}/nsutil.jar nsutil.jar



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

## This package currently contains no pre-installation process!
#%pre


%post
chmod 00755 %{_datadir}/%{base_prefix}/setup/postinstall
%{_datadir}/%{base_prefix}/setup/postinstall %{base_prefix}


## This package currently contains no pre-uninstallation process!
#%preun


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/java/%{base_prefix}
%attr(-,root,root)     %{_datadir}/%{base_prefix}/*
%attr(-,root,root)     %{_var}/lib/tomcat5/common/lib/*


%files javadoc
%defattr(0644,root,root,0755)
%dir %{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}-%{version}/*



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Tue Oct 30 2012 Jack Magne <jmagne@redhat.com> 8.1.3-2
- Bugzilla Bug #864397 - (CVE-2012-4543) EMBARGOED CVE-2012-4543 Certificate System: Multiple cross-site 
- scripting flaws by displaying CRL or processing profile.

* Mon Sep 10 2012 Jack Magne <jmagne@rehdat.com> 8.1.3-1
- Bugzilla Bug #852855 - remove unexpected anonymous binds to internal db in
  cert status thread. Fixed in errata 13744. Apply latest fix to issue.

* Fri Aug 31 2012 Ade Lee <alee@redhat.com> 8.1.2-1
- Bugzilla Bug #852855 - remove unexpected anonymous binds to internal db in 
  cert status thread. Fixed in errata 13744

* Mon Jun 4 2012 Andrew Wnuk <awnuk@redhat.com> 8.1.1-1
- Update version for errata 13235 containing bugzilla bugs 814478, 819508,
  547527.

* Thu Jan  5 2012 Christina Fu <cfu@redhat.com> 8.1.0-23
- Bugzilla Bug #769739 - CC: self test verifySystemCertByNickname: certain
  failure will not cause server to shutdown as expected (changed variable name)

* Wed Jan  4 2012 Christina Fu <cfu@redhat.com> 8.1.0-22
- Bugzilla Bug #769739 - CC: self test verifySystemCertByNickname: certain
  failure will not cause server to shutdown as expected

* Thu Dec 15 2011 Jack Magne <jmagne@redhat.com> 8.1.0-21
- Bugzilla Bug #748570 - CA console does not display Local certificates info
  when one of the cert in security db has long nickname string.

* Thu Nov 3 2011 Andrew Wnuk <awnuk@redhat.com> 8.1.0-20
- Bugzilla Bug #747019 - Migrated policy requests from 7.1->8.1 displays
  issuedcerts and cert_Info params as base 64 blobs.

* Wed Oct 19 2011 Christina Fu <cfu@redhat.com> - 8.1.0-19
- Bugzilla Bug #744797 - KRA key recovery (retrieve pkcs#12) fails after the
  in-place upgrade( CS 8.0->8.1)

* Fri Sep 16 2011 Jack Magne <jmagne@redhat.com> 8.1.0-18
- Bugzilla Bug #730162 - TPS/TKS token enrollment failure in FIPS mode
  (hsm+NSS). (jmagne)
- Bugzilla Bug #737218 - Incorrect request attribute name matching ignores
  request attributes during request parsing. (awnuk)

* Wed Sep 7 2011 Ade Lee <alee@redhat.com> 8.1.0-17
- Bugzilla Bug #733446 - In-place upgrade - Upgrading nuxwdog packages throws error,
  updated nuxwdog dependencies

* Thu Aug 25 2011 Ade Lee <alee@redhat.com> 8.1.0-16
- Bugzilla Bug #731741 - some CS.cfg nickname parameters not updated
  correctly when subsystem cloned (using hsm)

* Thu Aug 11 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-15
- Bugzilla Bug #717041 - Improve escaping of some enrollment inputs like
  (jmagne, awnuk)
- Bugzilla Bug #724848 - CC_LAB_EVAL: none-FIPS ciphers allowed in CC mode
  (cfu)

* Wed Jul 20 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-14
- Bugzilla Bug #720510 - Console: Adding a certificate into nethsm throws
  "Token not found" error. (alee)
- Bugzilla Bug #719007 - Key Constraint keyParameter being ignored using an
  ECC CA to generate ECC certs from CRMF (jmagne)
- Bugzilla Bug #716307 - rhcs80 - DER shall not include an encoding for any
  component value which is equal to its default value (alee)
- Bugzilla Bug #722989 - Registering an agent when a subsystem is created -
  does not log AUTHZ_SUCCESS event. (alee)

* Wed Jul 6 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-13
- Bugzilla Bug #707607 - Published certificate summary has list of
  non-published certificates with succeeded status (jmagne)
- Bugzilla Bug #717813 - EV_AUDIT_LOG_SHUTDOWN audit log not generated
  for tps and ca on server shutdown (alee, jmagne)
- Bugzilla Bug #697939 - DRM signed audit log message - operation should be
  read instead of modify. (jmagne)
- Bugzilla Bug #718427 - When audit log is full, server continue
  to function (alee)
- Bugzilla Bug #718607 - CC_LAB_EVAL: No AUTH message is generated in CA's
  signedaudit log when a directory based user enrollment is performed (jmagne)

* Tue Jun 7 2011 Ade Lee <alee@redhat.com> 8.1.0-12
- Bugzilla Bug #707416 - CC_LAB_EVAL: Security Domain: missing audit msgs
  for modify/add

* Wed May 25 2011 Andrew Wnuk <awnuk@redhat.com> 8.1.0-11
- Bugzilla Bug #705914 - SCEP mishandles nicknames when processing
  subsequent SCEP requests. (awnuk)
- Bugzilla Bug #661142 - Verification should fail when a revoked certificate
  is added. (jmagne)

* Mon Apr 25 2011 Ade Lee <alee@redhat.com> 8.1.0-10
- Bugzilla Bug #698885 - Race conditions during IPA installation (alee)
- Bugzilla Bug #704792 - CC_LAB_EVAL: CA agent interface:
  SubjectID=Unidentified fails audit evaluation (jmagne)

* Mon Apr 18 2011 Ade Lee <alee@redhat.com> 8.1.0-9
- Bugzilla Bug #697389 - failed authz on console creates incomplete audit log

* Sat Apr 16 2011 Jack Magne <jmagne@redhat.com> 8.1.0-8
- Bugzilla Bug #695015 - Serial No. of a revoked certificate is not
  populated in the CA signedAudit messages

* Fri Apr 15 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-7
- Bugzilla Bug #694569 - parameter used by pkiremove not updated (alee)
- Bugzilla Bug #695403 - Editing signedaudit or transaction, system logs
  throws 'Invalid protocol' for OCSP subsystems (alee)
- Bugzilla Bug #695015 - Serial No. of a revoked certificate is not
  populated in the CA signedAudit messages (jmagne)
- Bugzilla Bug #694143 - CA Agent not returning specified request (awnuk)

* Mon Apr 11 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-6
- Bugzilla Bug #695157 - Auditverify on TPS audit log throws error.

* Tue Apr 5 2011 Ade Lee <alee@redhat.com> 8.1.0-5
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1
- Bugzilla Bug #692990 - Audit log messages needed to match CC doc: DRM
  Recovery audit log message

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-4
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1
- fix nuxwdog BuildRequires

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-3
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Tue Dec 14 2010 Ade Lee <alee@redhat.com> 8.1.0-2
- Bugzilla Bug #663116 - Update nuxwdog dependencies

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Mon Nov 30 2009 Ade Lee <alee@redhat.com> 8.0.1-6
- Bugzilla Bug #518123 - rename pkidog to nuxwdog

* Mon Nov 23 2009 Ade Lee <alee@redhat.com> 8.0.1-5
- Bugzilla Bug #518123 - Prompt for passwords if password.conf is removed

* Wed Nov 18 2009 Ade Lee <alee@redhat.com> 8.0.1-4
- Bugzilla Bug #528236 - rhcs80 web conf wizard - cannot specify CA signing algorithm

* Tue Aug 25 2009 Christina Fu <cfu@redhat.com> 8.0.1-3
- Bugzilla Bug #465507 - Enhancement: Support SHA2 + EC signature algorithms
- Added to errata RHBA-2009:8830 containing Bugzilla Bugs 224688, 512828,
  513450, 514093, 514094, 514270, 465507, 518431

* Thu Aug 20 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.1-2
- Update version for errata RHBA-2009:8830-01 to include 224688, 512828, 513450,
  514093, 514094, 514270 and 518431

* Tue Aug 18 2009 Ade Lee <alee@redhat.com> 8.0.1-1
- Update version for errata containing Bugzilla bugs 224688, 512828, 513450, 
  514093, 514094, 514270

* Tue Aug 4 2009 Ade Lee <alee@redhat.com> 8.0.0-17
- Bugzilla Bug #224688 - Support ECC POP on the server 

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-16
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-15
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-14
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-13
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Wed Jun 3 2009 Christina Fu <cfu@redhat.com> 8.0.0-12
- Bugzilla Bug #455305 - CA ECC signing Key Failure
  Bugzilla Bug #223279 - ECC: Ca: unable to perform agent auth on a machine with nCipher ECC HSM
* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-11
- Bugzilla Bug #499030 -  Beta 2 Release

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-9
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Sat Feb 14 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-8
- Bugzilla Bug #250874 -Change spec file dependencies to rely on latest
  versions of components (NSPR, NSS, JSS, MOD_NSS)

* Fri Feb 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-7
- Bugzilla Bug #485522 -  Need rpm spec file to require xerces-j2
- required to build javadocs

* Thu Feb 12 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-6
- Bugzilla Bug #483699 -  problem with the epoch in the spec file causes
  build to fail

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-5
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"
- Bugzilla Bug #441974 - Added "Conflicts: tomcat-native" statement to
                         spec file

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Fri Jun 8 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- bugzilla bug #241961 - added javadocs subpackage; added legacy upgrade path

* Tue Jun 5 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-2
- bugzilla bug #242575 - Made numerous changes to spec file.

* Fri Jun 1 2007 Thomas Kwan <nkwan@redhat.com> 8.0.0-1
- Update version to 8.0.0

